@@ -15,8 +15,7 @@ BEGIN {
     @EXPORT_OK = qw(
 	calc_geom 
 	check_file 
-	exist_pdb_code_on_obsoletes 
-	exist_pdb_code_on_uncompressed 
+    get_pdb_path_fh
 	get_full_path_name_for_pdb_code 
 	get_from_file 
 	translate 
@@ -170,10 +169,11 @@ sub check_file {
 
 =head2 _getReadingFileHandle
 	
-    subroutine to get a reading file handle
-        for a file.
-
-        input: file path name to the file 
+    subroutine to get a reading file handle for a file.
+    input : full path name
+    output: file handler 
+   
+    die on error
 =cut
 
 sub _getReadingFileHandle {
@@ -181,147 +181,18 @@ sub _getReadingFileHandle {
 
     my $file = shift;
     die "path_name files is required" unless $file;
-
+    
     my $fh;
     if ( $file =~ /\.gz$/ ) {
-        $fh = new IO::Uncompress::Gunzip $file || die("Cannot open $file");
+        $fh = new IO::Uncompress::Gunzip "$file" 
+            or die "Cannot open $file $!";
     }
     else {
-        open( $fh, "< $file" ) || die("Cannot open $file");
+        open $fh, '<', "$file" or die "Cannot open $file $!";
     }
     return $fh;
 }
 
-=head2 exist_pdb_code_on_obsoletes
-	check if a four-letters pdb code exist in PDB obsoletes folder
-	it will return the full path name if a match is found.
-	return undef if not file was found
-	
-        exist_pdb_code_on_obsoletes
-	input  : pdb_code (4fab)
-	return : full path name
-
-=cut
-
-sub exist_pdb_code_on_obsoletes {
-    use File::Spec::Functions qw(catfile);
-    
-    my ($pdb_code) = @_;
-    croak "exist_pdb_code_on_obsoletes: pdb_code is required" 
-        unless $pdb_code;
-
-    chomp $pdb_code;
-    croak "$pdb_code does not look like a four-letter PDB_CODE"
-      unless $pdb_code =~ /[A-z0-9]{4}/;
-
-    my $pdb_file_name    = "pdb" . $pdb_code . '.ent';
-    my $pdb_file_name_gz = "pdb" . $pdb_code . '.ent.gz';
-
-    # my $uncompressed = "$PDB_PATH/obsoletes/$pdb_file_name";
-    # my $compressed   = "$PDB_PATH/obsoletes/$pdb_file_name_gz";
-    my $uncompressed = catfile($PDB_PATH, 'obsoletes', $pdb_file_name);
-    my $compressed   = catfile($PDB_PATH, 'obsoletes', $pdb_file_name_gz);
-
-    # try uncompressed pdb filename existence
-    if ( -e $uncompressed ) {
-        return $uncompressed;
-    }
-
-    # try compressed file
-    elsif ( -e $compressed ) {
-        return $compressed;
-    }
-    else {
-        return undef;
-    }
-}
-
-=head2 exist_pdb_code_on_uncompressed
-
-	check if a four-letters pdb code exist in uncompressed PDB folder
-	it will return the full path name if a match is found.
-	Return undef if not file was found
-	
-        input  : pdb_code (4fab)
-	return : full path name
-
-=cut
-
-sub exist_pdb_code_on_uncompressed {
-    use File::Spec::Functions qw(catfile);
-
-    my ($pdb_code) = @_;
-    croak "exist_pdb_code_on_uncompressed: pdb_code is required" 
-        unless $pdb_code;
-
-    chomp $pdb_code;
-    croak "$pdb_code does not look like a four-letter PDB_CODE"
-      unless $pdb_code =~ /[A-z0-9]{4}/;
-
-    my $pdb_file_name    = "pdb" . $pdb_code . '.ent';
-    my $pdb_file_name_gz = "pdb" . $pdb_code . '.ent.gz';
-
-    # my $uncompressed = "$PDB_PATH/uncompressed/$pdb_file_name";
-    # my $compressed   = "$PDB_PATH/uncompressed/$pdb_file_name_gz";
-    my $uncompressed = catfile($PDB_PATH, 'uncompressed', $pdb_file_name);
-    my $compressed   = catfile($PDB_PATH, 'uncompressed', $pdb_file_name_gz);
-
-    # try uncompressed pdb filename existence
-    if ( -e $uncompressed ) {
-        return $uncompressed;
-    }
-
-    # try compressed file
-    elsif ( -e $compressed ) {
-        return $compressed;
-    }
-    else {
-        return undef;
-    }
-}
-
-=head2 exist_pdb_code_on_alternate
-
-	check if a four-letters pdb code exist in user defined alternate 
-	PDB folder
-        it will return the full path name if a match is found.
-	Return undef if not file was found
-	
-        input  : pdb_code (4fab)
-	return : full path name
-
-=cut
-
-sub exist_pdb_code_on_alternate { 
-    my ($pdb_code) = @_;
-    croak "exist_pdb_code_on_alternate: pdb_code is required" 
-        unless $pdb_code;
-
-    chomp $pdb_code;
-    croak "$pdb_code does not look like a four-letter PDB_CODE"
-      unless $pdb_code =~ /[A-z0-9]{4}/;
-
-    my $pdb_file_name    = "pdb" . $pdb_code . '.ent';
-    my $pdb_file_name_gz = "pdb" . $pdb_code . '.ent.gz';
-
-    # my $uncompressed = "$USER_SPECIFIC_PDB_PATH/$pdb_file_name";
-    # my $compressed   = "$USER_SPECIFIC_PDB_PATH/$pdb_file_name_gz";
-    my $uncompressed = catfile($USER_SPECIFIC_PDB_PATH, $pdb_file_name);
-    my $compressed   = catfile($USER_SPECIFIC_PDB_PATH, $pdb_file_name_gz);
-
-    # try uncompressed pdb filename existence
-    if ( -e $uncompressed ) {
-        return $uncompressed;
-    }
-
-    # try compressed file
-    elsif ( -e $compressed ) {
-        return $compressed;
-    }
-    else {
-        return undef;
-    }
-}
 
 =head2 get_full_path_name_for_pdb_code
 	Return a fullpath name for a given four-letter PDB code	
@@ -416,39 +287,7 @@ sub get_full_path_name_for_pdb_code {
     croak "Could not find $pdb_code on $PDB_PATH/obsoletes, $PDB_PATH/uncompressed or $USER_SPECIFIC_PDB_PATH"
       unless $file_full_path[0];
 }
-sub get_full_path_name_for_pdb_code_old {
-    use Data::Dumper;
-    my ($pdb_code) = @_;
-   
-    if ($DEBUG){
-	    my  ($package, $filename, $line) = caller;
-	    print "function: get_full_path_name_for_pdb_code\n";
-        print "package  = $package\n";
-	    print "filename = $filename\n";
-	    print "line     = $line\n";
-	    print Dumper(\@_);
-    }
 
-    croak "get_full_path_name_for_pdb_code: pdb_code is required" 
-        unless $pdb_code;
-
-    chomp $pdb_code;
-    croak "$pdb_code does not look like a four-letter PDB_CODE"
-      unless $pdb_code =~ /[A-z0-9]{4}/;
-
-    my $path;
-    $path = exist_pdb_code_on_uncompressed($pdb_code);
-    return $path if $path;
-
-    $path = exist_pdb_code_on_obsoletes($pdb_code);
-    return $path if $path;
-    
-    $path = exist_pdb_code_on_alternate($pdb_code);
-    return $path if $path;
-
-    croak "Could not find $pdb_code on $PDB_PATH/obsoletes, $PDB_PATH/uncompressed or $USER_SPECIFIC_PDB_PATH"
-      unless $path;
-}
 
 =head2 get_from_file
 
@@ -473,8 +312,9 @@ sub get_full_path_name_for_pdb_code_old {
 
 =cut
 
+
 sub get_from_file {
-    my ( $data, $landmarks, $string, $seq ) = @_;
+    my ( $data, $landmarks, $string, $seq, $fh ) = @_;
 
     # data contains pdbid, chain, start, ss1, ss2
     use Data::Dumper;
@@ -487,46 +327,16 @@ sub get_from_file {
     @$landmarks =
       ( $$data[3], $$data[3] + $$data[5], $$data[3] + $$data[5] + $$data[4] );
 
-    # $$data[0] has values like this:
-    # 2kl8/pdb2kl8.ent
-    my $pdb_code;
-     
-    print "Looking for data[0] = $$data[0]\n" if $DEBUG;
-    if ( $$data[0] =~ /\// ) {
-        # $pdb_code = ( split( /\//, $$data[0] ) )[0];
-        my $filename = basename $$data[0];
-        if ( $filename =~ /pdb(\w{4}).*/ ) {
-            $pdb_code =  $1;
-        } 
-        elsif ( $filename =~ /(\w{4}).*/ ) {
-            $pdb_code =  $1;
-        }
-        else {} 
-    }
-    else {
-        $pdb_code = $$data[0];
-        $pdb_code =~ s/^pdb//g;     # removing leading pdb string
-        $pdb_code =~ s/\.(\w+)$//g; # removing file extension
-    }
-    
-    #unless ( $$data[0] ) {
-    #   use Data::Dumper;
-    #   print "pdb_code $pdb_code\n";
-    #   print Dumper($data);
-    #   #croak "get_from_file: pdb_code is required";
-    #}
-    my $full_path_name = get_full_path_name_for_pdb_code($pdb_code);
-    my $fh             = _getReadingFileHandle($full_path_name);
-
     my $done    = 0;
     my @coords  = ();
     my $prevres = 0;
     my $len     = length($string);
     my $id      = $prevres;
-    if ( $string ne 'CB' )
-    { #certain residues (GLY) will not have CBs, so this case has to be treated separately
+    # certain residues (GLY) will not have CBs, so this case has to be treated separately
+    if ( $string ne 'CB' ) {
         while ( defined( my $line = <$fh> ) and ( $done == 0 ) ) {
             chomp($line);
+            # print "LINE = $line\n";
             if ( $line =~
                 /ATOM\s+-*\d+\s+$string\s+(\w+)\s$chain\s*(-*\d+\w?\s)/ )
             {
@@ -562,6 +372,7 @@ sub get_from_file {
         my $prevline = <$fh>;
         while ( defined( my $line = <$fh> ) and ( $done == 0 ) ) {
             chomp($line);
+            # print "LINE = $line\n";
             if ( $line =~ /ATOM\s+-*\d+\s+CB\s+(\w+)\s$chain\s*(-*\d+\w?\s)/ ) {
                 $id = $2;
                 my $amin = substr( $1, -3, 3 );
@@ -606,10 +417,63 @@ sub get_from_file {
             $prevline = $line;
         }
     }
-    close($fh);
+    #close($fh);
+    #print Dumper(\@coords);
     return @coords;
 }
 
+=head2 get_pdb_path_fh
+	
+	it will return the full path name for a pdb_code_id 
+    if a match is found in PDB folder.
+	die if not file was found
+     
+	input  : vilas (@array)
+	return : full path name
+
+=cut
+
+sub get_pdb_path_fh  {
+    
+    # data contains pdbid, chain, start, ss1, ss2
+    use Data::Dumper;
+    use File::Basename;
+    
+    my ( $data ) = @_;
+    die "get_pdb_path_fh required array" unless @$data;
+   
+    # print Dumper(\$data);
+    # $$data[0] has values like this:
+    # 2kl8/pdb2kl8.ent
+    my $pdb_code;
+     
+    print "Looking for data[0] = $$data[0]\n" if $DEBUG;
+    if ( $$data[0] =~ /\// ) {
+        my $filename = basename $$data[0];
+        if ( $filename =~ /pdb(\w{4}).*/ ) {
+            $pdb_code =  $1;
+        } 
+        elsif ( $filename =~ /(\w{4}).*/ ) {
+            $pdb_code =  $1;
+        }
+        else {} 
+    }
+    else {
+        $pdb_code = $$data[0];
+        $pdb_code =~ s/^pdb//g;     # removing leading pdb string
+        $pdb_code =~ s/\.(\w+)$//g; # removing file extension
+    }
+    die "Could not extract pdb_code_id from $$data[0]" 
+        unless $pdb_code;
+
+    my $full_path_name = get_full_path_name_for_pdb_code($pdb_code);
+    
+    die "get_pdb_path_fh: Could not find path for $pdb_code" 
+        unless $full_path_name;
+    
+    return $full_path_name; 
+}
+
 =head2 translate2
 
 	translate 
