@@ -285,8 +285,8 @@ sub add_motif {
 	my ($self, @proptable) = @_;
 	my $check;
 
-        my $DEBUG = 0;
-        if ($DEBUG){
+    my $DEBUG = 0;
+    if ($DEBUG){
             print Dumper(\@proptable);
 		    my  ($package, $filename, $line) = caller;
 		    print "package  = $package\n";
@@ -296,13 +296,13 @@ sub add_motif {
 	}
 
 	if ($self->num_motifs() == 0 ) {
-                # print "add_motif_from_file\n";
+        # print "add_motif_from_file\n";
 		$check = $self->add_motif_from_file(@proptable);
-        } 
+    } 
 	else {
-                # print "add_partial_motif\n";
+       # print "add_partial_motif\n";
 		$check = $self->add_partial_motif(@proptable);
-        };
+    };
 	return $check;
 }
 
@@ -333,14 +333,39 @@ sub add_motif_from_file {
 		# GeometricalCalculations::getnid(\@proptable, \@idtable);
 		# print Dumper(\@proptable);
 		# print Dumper(\@idtable);
-               SmotifCS::MYSQLSmotifs::getnid(\@proptable, \@idtable);
+        SmotifCS::MYSQLSmotifs::getnid(\@proptable, \@idtable);
+		#print Dumper(\@idtable);
+
 	}
-	my @ca = SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CA',\$seq);
+    # print "start get_from_file\n";
+	my $fpath = SmotifCS::GeometricalCalculations::get_pdb_path_fh(\@idtable);
+    my $fh    = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
+    my @ca = SmotifCS::GeometricalCalculations::get_from_file( \@idtable, \@lm, 'CA', \$seq, $fh);
+    close $fh;
+
+    $fh    = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
+    my @n  = SmotifCS::GeometricalCalculations::get_from_file( \@idtable, \@lm, 'N' , \$seq, $fh);
+    close $fh;
+    
+    $fh    = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
+	my @c  = SmotifCS::GeometricalCalculations::get_from_file( \@idtable, \@lm, 'C' , \$seq, $fh);
+    close $fh;
+    
+    $fh    = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
+	my @cb = SmotifCS::GeometricalCalculations::get_from_file( \@idtable, \@lm, 'CB', \$seq, $fh);
+    close $fh;
+    
+    $fh    = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
+	my @o  = SmotifCS::GeometricalCalculations::get_from_file( \@idtable, \@lm, 'O' , \$seq, $fh);
+    close $fh;
+=for	
+    my @ca = SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CA',\$seq);
 	my @n  = SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'N',\$seq);
 	my @c  = SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'C',\$seq);
 	my @cb = SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CB',\$seq);
 	my @o  = SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'O',\$seq);
-	#print scalar(@ca),"\t",scalar(@n),"\t",scalar(@c),"\t",scalar(@cb),"\t",scalar(@o),"\n";
+=cut    
+    # print scalar(@ca),"\t",scalar(@n),"\t",scalar(@c),"\t",scalar(@cb),"\t",scalar(@o),"\n";
 	#look for missing cb atoms (from glycines)
 	for (my $aa=0;$aa<scalar(@cb);$aa++) {
 		if ($cb[$aa]==0) {
@@ -349,11 +374,11 @@ sub add_motif_from_file {
 	}
 	unshift(@lm,0);
 	for (my $aa=0;$aa<$lm[3];$aa++) {
-		push(@{$self->{ca}},$ca[$aa]);
-		push(@{$self->{c}},$c[$aa]);
-		push(@{$self->{n}},$n[$aa]);
-		push(@{$self->{cb}},$cb[$aa]);
-		push(@{$self->{o}},$o[$aa]);
+		push(@{$self->{ca}},$ca[$aa] );
+		push(@{$self->{c}}, $c[$aa]  );
+		push(@{$self->{n}}, $n[$aa]  );
+		push(@{$self->{cb}},$cb[$aa] );
+		push(@{$self->{o}}, $o[$aa]  );
 	}
 	$self->one_landmark(-1,@lm);
 	$self->{num}++;
@@ -394,11 +419,33 @@ sub add_partial_motif {
 		# GeometricalCalculations::getnid(\@proptable, \@idtable);
 		SmotifCS::MYSQLSmotifs::getnid(\@proptable, \@idtable);
 	}
-	my @ca=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CA',\$seq);
+    my $fpath = SmotifCS::GeometricalCalculations::get_pdb_path_fh(\@idtable);
+    my $fh = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
+	my @ca=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CA',\$seq, $fh);
+    close $fh;
+	
+    $fh = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
+    my @n=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'N',\$seq, $fh);
+    close $fh;
+	
+    $fh = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
+    my @c=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'C',\$seq, $fh);
+    close $fh;
+	
+    $fh = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
+    my @cb=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CB',\$seq, $fh);
+    close $fh;
+	
+    $fh = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
+    my @o=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'O',\$seq, $fh);
+    close $fh;
+=for	
+    my @ca=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CA',\$seq);
 	my @n=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'N',\$seq);
 	my @c=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'C',\$seq);
 	my @cb=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CB',\$seq);
 	my @o=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'O',\$seq);
+=cut
 	# generate missing C-beta atoms for glycine residues
 	for (my $aa=0;$aa<scalar(@cb);$aa++) {
 		if ($cb[$aa]==0) {
